<?php
/**
 * SkeletonCart
 * (c) 2017-2023 Juxtaposition Inc. All Rights Reserved.
 * (c) 2017-2023 Curlybracket, Inc. All Rights Reserved.
 * This code cannot be redistributed without permission from the copyright holder.
 * For more information, consult your SkeletonCart license.
 **/

namespace OptionPrice;

class Plugin extends \App\Plugin
{
    protected $priceList = array();

    public function __construct($key)
    {
        parent::__construct($key);

        $fileName = __DIR__ . "/Config.php";
        if (!is_readable($fileName)) {
            throw new \RuntimeException("オプション価格表が読み込めません。");
        }
        $this->priceList = include $fileName;

        $this->initCallbacks();
    }

    public function initCallbacks()
    {
        \App::addCallback('updateCartItem', array($this, 'updateCartItem'));
    }

    protected function getPriceListForOption($optionId)
    {
        if (isset($this->priceList) && isset($this->priceList[$optionId])) {
            return $this->priceList[$optionId];
        }
        return null;
    }

    public function updateCartItem($cartItem)
    {
        $totalOptionsPrice = 0;
        foreach ($cartItem->options() as $n => $values) {
            $priceList = $this->getPriceListForOption($n);
            if (is_null($priceList)) {
                continue;
            }
            if (!is_array($values) || !array_key_exists('value', $values)) {
                continue;
            }
            $optionValue = $values['value'];
            if (array_key_exists($optionValue, $priceList)) {
                $values['price'] = $priceList[$optionValue];
                $totalOptionsPrice += $priceList[$optionValue];
                $cartItem->setOption($n, $values);
            }
        }
        $cartItem->setPrice($cartItem->unitPrice() + $totalOptionsPrice);
        $cartItem->setTotalPrice($cartItem->price() * $cartItem->amount());
    }
}

\App::addPlugin(new Plugin('OptionPrice'));
